SubZeroAddItemConfig class
Configuration for the SubZeroAddItem component.
Constructors
Properties
- addButtonText → String
-
Text displayed on the add button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialQuantity → int
-
Initial quantity when transitioning to quantity mode.
final
- maxQuantity → int
-
Maximum allowed quantity (capped at 99 for 2-digit display).
final
- minQuantity → int
-
Minimum allowed quantity (typically 0 or 1).
final
- moreButtonText → String
-
Text displayed on the "more" button (if enabled).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMoreOption → bool
-
Whether to show the "More" button with dropdown.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited