initials property
Initials to display when image is not available (e.g., "JD" for "Jane Doe"). Only the first 2 characters will be displayed.
Implementation
final String? initials;
Initials to display when image is not available (e.g., "JD" for "Jane Doe"). Only the first 2 characters will be displayed.
final String? initials;