semanticLabel property
Semantic label for accessibility (required when image is displayed).
This text is read by screen readers to describe the avatar image.
Implementation
final String? semanticLabel;
Semantic label for accessibility (required when image is displayed).
This text is read by screen readers to describe the avatar image.
final String? semanticLabel;