SubZeroAvatarSize enum

Size variants for SubZeroAvatar.

Based on SubZero 2.0 Design System specifications.

Inheritance
Available extensions

Values

s → const SubZeroAvatarSize

Small: 24px diameter

const SubZeroAvatarSize(24)
m → const SubZeroAvatarSize

Medium: 32px diameter

const SubZeroAvatarSize(32)
l → const SubZeroAvatarSize

Large: 40px diameter

const SubZeroAvatarSize(40)
xl → const SubZeroAvatarSize

Extra Large: 48px diameter

const SubZeroAvatarSize(48)
xxl → const SubZeroAvatarSize

Double Extra Large: 64px diameter

const SubZeroAvatarSize(64)
threeXL → const SubZeroAvatarSize

Triple Extra Large: 80px diameter

const SubZeroAvatarSize(80)

Properties

diameter double
The diameter in logical pixels.
final
fontSize double
Returns the font size proportional to the avatar size.
no setter
hashCode int
The hash code for this object.
no setterinherited
iconSize double
Returns the icon size proportional to the avatar size.
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubZeroAvatarSize>
A constant List of the values in this enum, in order of their declaration.