iconSize property
double
get
iconSize
Returns the icon size proportional to the avatar size.
Implementation
double get iconSize => diameter * 0.5;
Returns the icon size proportional to the avatar size.
double get iconSize => diameter * 0.5;