SubZeroBadgeAlignment class

Configuration for SubZeroBadge positioning and offset

Constructors

SubZeroBadgeAlignment({SubZeroBadgePosition position = SubZeroBadgePosition.topRight, Offset offset = Offset.zero})
const

Properties

alignment AlignmentGeometry
Get the alignment based on position
no setter
hashCode int
The hash code for this object.
no setterinherited
offset Offset
final
position SubZeroBadgePosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited