SubZeroBadgeSize enum
Badge size presets
Values
- small → const SubZeroBadgeSize
-
Small badge (16px height for count, 8px for dot)
- medium → const SubZeroBadgeSize
-
Medium badge (20px height for count, 10px for dot) - default
- large → const SubZeroBadgeSize
-
Large badge (24px height for count, 12px for dot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SubZeroBadgeSize> - A constant List of the values in this enum, in order of their declaration.