SubZeroBadgeStyle enum

Badge style/color variants matching the SubZero Design System

Inheritance
Available extensions

Values

filled → const SubZeroBadgeStyle

Primary filled style - accent background with white text

outlined → const SubZeroBadgeStyle

Outlined style - white background with accent text and border

muted → const SubZeroBadgeStyle

Muted/disabled style - gray background with gray text

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubZeroBadgeStyle>
A constant List of the values in this enum, in order of their declaration.