topContentOverflows property
Whether the top content should overflow outside the sheet (mobile only).
Implementation
final bool topContentOverflows;
Whether the top content should overflow outside the sheet (mobile only).
final bool topContentOverflows;