components/subzero_button library

Classes

SubZeroButton
A flexible, accessible button widget following the SubZero 2.0 Design System.
SubZeroButtonGroup
A container widget that arranges a set of related buttons in a horizontal row.
SubZeroConnectedButtonGroup
A connected button group where buttons are visually joined together.

Enums

SubZeroButtonSize
Button size presets
SubZeroButtonVariant
Button variant types following SubZero 2.0 Design System