SubZeroButtonVariant enum
Button variant types following SubZero 2.0 Design System
Values
- primary → const SubZeroButtonVariant
-
Solid background, high emphasis (primary action)
- secondary → const SubZeroButtonVariant
-
Bordered, medium emphasis (secondary action)
- tertiary → const SubZeroButtonVariant
-
Minimal/text only, low emphasis (tertiary action)
- iconOnly → const SubZeroButtonVariant
-
Icon-only button (square)
- flushed → const SubZeroButtonVariant
-
Flushed: same as primary but with zero border radius
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SubZeroButtonVariant> - A constant List of the values in this enum, in order of their declaration.