SubZeroCardMediaRatio enum

Media aspect ratio presets following Figma specifications. All ratios are width:height (x:y).

Inheritance
Available extensions

Values

wide → const SubZeroCardMediaRatio

1:0.5 - Wide landscape (width is 2x height)

const SubZeroCardMediaRatio(2.0)
square → const SubZeroCardMediaRatio

1:1 - Square

const SubZeroCardMediaRatio(1.0)
standard → const SubZeroCardMediaRatio

4:3 - Standard landscape

const SubZeroCardMediaRatio(4 / 3)
portrait → const SubZeroCardMediaRatio

1:1.5 - Portrait (height is 1.5x width)

const SubZeroCardMediaRatio(1 / 1.5)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubZeroCardMediaRatio>
A constant List of the values in this enum, in order of their declaration.