components/subzero_checkbox library

Classes

SubZeroCheckbox
A customizable checkbox widget following SubZero 2.0 Design System.
SubZeroCheckboxGroup<T>
A horizontal checkbox group for displaying checkboxes in a row
SubZeroMultiselectConfig
Configuration for SubZeroMultiselectList
SubZeroMultiselectList<T>
A stateful multiselect list component that manages multiple checkbox selections.
SubZeroMultiselectOption<T>
Data model for a multiselect option

Enums

SubZeroCheckboxSize
Size options for checkbox
SubZeroCheckboxState
Checkbox state for tristate support