SubZeroCheckboxGroup<T> class

A horizontal checkbox group for displaying checkboxes in a row

Inheritance
Available extensions

Constructors

SubZeroCheckboxGroup({Key? key, required List<SubZeroMultiselectOption<T>> options, required List<T> selectedValues, required ValueChanged<List<T>> onChanged, double spacing = SubZeroSpacing.lg, SubZeroCheckboxSize size = SubZeroCheckboxSize.medium, bool enabled = true, bool wrap = false, double runSpacing = SubZeroSpacing.sm, Color? activeColor})
const

Properties

activeColor Color?
Custom active color
final
enabled bool
Whether all checkboxes are enabled
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<List<T>>
Callback when selection changes
final
options List<SubZeroMultiselectOption<T>>
List of available options
final
runSpacing double
Vertical spacing when wrapped
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValues List<T>
Currently selected values
final
size SubZeroCheckboxSize
Size of checkboxes
final
spacing double
Horizontal spacing between checkboxes
final
wrap bool
Whether to wrap to next line
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withCountBadge({required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a count badge
withDotBadge({SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a dot badge

Operators

operator ==(Object other) bool
The equality operator.
inherited