SubZeroMultiselectConfig class
Configuration for SubZeroMultiselectList
Constructors
- SubZeroMultiselectConfig({bool showSelectAll = true, String selectAllLabel = 'All', SubZeroCheckboxSize size = SubZeroCheckboxSize.medium, double spacing = SubZeroSpacing.md, Color? activeColor, bool scrollable = false, double? maxHeight})
-
const
Properties
- activeColor → Color?
-
Custom active color for checkboxes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxHeight → double?
-
Maximum height when scrollable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
Whether the list is scrollable
final
- selectAllLabel → String
-
Label for the "Select All" checkbox
final
- showSelectAll → bool
-
Whether to show "Select All" checkbox at the top
final
- size → SubZeroCheckboxSize
-
Size of checkboxes
final
- spacing → double
-
Vertical spacing between items
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited