SubZeroMultiselectList<T> class
A stateful multiselect list component that manages multiple checkbox selections.
Supports "Select All" functionality with indeterminate state when partially selected.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SubZeroMultiselectList
- Available extensions
Constructors
-
SubZeroMultiselectList({Key? key, required List<
SubZeroMultiselectOption< options, required List<T> >T> selectedValues, required ValueChanged<List< onChanged, SubZeroMultiselectConfig config = const SubZeroMultiselectConfig(), bool enabled = true, String? semanticLabel})T> > -
const
Properties
- config → SubZeroMultiselectConfig
-
Configuration for the multiselect list
final
- enabled → bool
-
Whether the entire list is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
List< T> > -
Callback when selection changes
final
-
options
→ List<
SubZeroMultiselectOption< T> > -
List of available options
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedValues
→ List<
T> -
Currently selected values
final
- semanticLabel → String?
-
Semantic label for the group
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SubZeroMultiselectList< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited