SubZeroMultiselectOption<T> class

Data model for a multiselect option

Constructors

SubZeroMultiselectOption({required T value, required String label, bool enabled = true, String? semanticLabel})
const

Properties

enabled bool
Whether this option is enabled
final
hashCode int
The hash code for this object.
no setterinherited
label String
Display label for the option
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Semantic label for accessibility
final
value → T
The value associated with this option
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited