SubZeroDialogActions class

Configuration for dialog actions

Constructors

SubZeroDialogActions({required String primaryLabel, VoidCallback? onPrimary, String? secondaryLabel, VoidCallback? onSecondary, bool primaryLoading = false, IconData? primaryTrailingIcon})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onPrimary VoidCallback?
Primary action callback
final
onSecondary VoidCallback?
Secondary action callback
final
primaryLabel String
Primary action button label (right side or flushed)
final
primaryLoading bool
Whether primary button shows loading state
final
primaryTrailingIcon IconData?
Optional trailing icon for flushed button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryLabel String?
Secondary action button label (left side, only for sideBySide layout)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited