length property
The extent of the divider in the main axis direction.
- For horizontal: the width (defaults to double.infinity)
- For vertical: the height (required for vertical dividers)
Implementation
final double? length;
The extent of the divider in the main axis direction.
final double? length;