SubZeroHeaderVariant enum

Header variants matching SubZero 2.0 Design System

Inheritance
Available extensions

Values

primary → const SubZeroHeaderVariant

Primary burgundy header with brand logo

surface → const SubZeroHeaderVariant

White/surface header with product branding

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubZeroHeaderVariant>
A constant List of the values in this enum, in order of their declaration.