SubZeroRadio<T> class

A customizable radio button widget following SubZero 2.0 Design System.

This is a stateless widget that displays selected/unselected states. Use SubZeroRadioGroup to manage a group of radio buttons.

Inheritance
Available extensions

Constructors

SubZeroRadio({Key? key, required T value, required T? groupValue, required ValueChanged<T?>? onChanged, String? label, bool enabled = true, SubZeroRadioSize size = SubZeroRadioSize.medium, String? semanticLabel, TextStyle? labelStyle, Color? activeColor, Color? borderColor})
const

Properties

activeColor Color?
Custom active (selected) color
final
borderColor Color?
Custom border color for unselected state
final
enabled bool
Whether the radio button is enabled
final
groupValue → T?
The currently selected value for the group
final
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
Whether this radio button is currently selected
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional text label displayed next to the radio button
final
labelStyle TextStyle?
Custom label text style
final
onChanged ValueChanged<T?>?
Callback when this radio button is selected
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Semantic label for accessibility
final
size SubZeroRadioSize
Size of the radio button
final
value → T
The value represented by this radio button
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SubZeroRadio<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withCountBadge({required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a count badge
withDotBadge({SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a dot badge

Operators

operator ==(Object other) bool
The equality operator.
inherited