SubZeroSearchSuggestion class
A search suggestion item data model
Constructors
- SubZeroSearchSuggestion({required String text, IconData? icon, String? subtitle})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Optional leading icon (defaults to history clock icon)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional subtitle for additional context
final
- text → String
-
The suggestion text to display
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited