SubZeroSearchWithSuggestions class
A search field with integrated suggestions dropdown.
Combines SubZeroSearchField with a dropdown list of suggestions that appears when the field is focused and has matching suggestions.
Example usage:
SubZeroSearchWithSuggestions(
hintText: 'Search products...',
suggestions: recentSearches,
onSuggestionSelected: (suggestion) => performSearch(suggestion.text),
onSubmitted: (query) => performSearch(query),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SubZeroSearchWithSuggestions
- Available extensions
Constructors
-
SubZeroSearchWithSuggestions({Key? key, String hintText = 'Search here', List<
SubZeroSearchSuggestion> suggestions = const [], ValueChanged<SubZeroSearchSuggestion> ? onSuggestionSelected, ValueChanged<String> ? onSubmitted, ValueChanged<String> ? onChanged, VoidCallback? onMicrophoneTap, bool showMicrophone = true, SubZeroSearchSize size = SubZeroSearchSize.medium, int maxSuggestions = 5}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String
-
Placeholder text for the search field
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxSuggestions → int
-
Maximum number of suggestions to display
final
-
onChanged
→ ValueChanged<
String> ? -
Callback when text changes (for filtering suggestions)
final
- onMicrophoneTap → VoidCallback?
-
Callback when microphone is tapped
final
-
onSubmitted
→ ValueChanged<
String> ? -
Callback when the query is submitted
final
-
onSuggestionSelected
→ ValueChanged<
SubZeroSearchSuggestion> ? -
Callback when a suggestion is selected
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMicrophone → bool
-
Whether to show the microphone icon
final
- size → SubZeroSearchSize
-
Size preset for the search field
final
-
suggestions
→ List<
SubZeroSearchSuggestion> -
List of suggestions to display
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SubZeroSearchWithSuggestions> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited