SubZeroRangeSlider class

A range slider that allows selecting a range between two values

Example:

SubZeroRangeSlider(
  values: RangeValues(_minPrice, _maxPrice),
  min: 0,
  max: 1000,
  onChanged: (values) => setState(() {
    _minPrice = values.start;
    _maxPrice = values.end;
  }),
)
Inheritance
Available extensions

Constructors

SubZeroRangeSlider({Key? key, required RangeValues values, double min = 0.0, double max = 1.0, int? divisions, ValueChanged<RangeValues>? onChanged, ValueChanged<RangeValues>? onChangeStart, ValueChanged<RangeValues>? onChangeEnd, bool showTooltip = true, String valueFormatter(double)?, String? minLabel, String? maxLabel, bool enabled = true, double trackHeight = 4.0, double thumbRadius = 12.0})
const

Properties

divisions int?
The number of discrete divisions.
final
enabled bool
Whether the slider is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
max double
The maximum value.
final
maxLabel String?
Label for the maximum end.
final
min double
The minimum value.
final
minLabel String?
Label for the minimum end.
final
onChanged ValueChanged<RangeValues>?
Called when the range changes.
final
onChangeEnd ValueChanged<RangeValues>?
Called when the user stops dragging.
final
onChangeStart ValueChanged<RangeValues>?
Called when the user starts dragging.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTooltip bool
Whether to show tooltips.
final
thumbRadius double
Radius of the thumb.
final
trackHeight double
Height of the track.
final
valueFormatter String Function(double)?
Custom formatter for the tooltip values.
final
values RangeValues
The current range values.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SubZeroRangeSlider>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withCountBadge({required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a count badge
withDotBadge({SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) Widget

Available on Widget, provided by the SubZeroBadgeExtension extension

Wrap this widget with a dot badge

Operators

operator ==(Object other) bool
The equality operator.
inherited