SubZeroSwitch class
A segmented toggle switch following SubZero 2.0 Design System.
Displays two options (default: YES/NO) in a pill-shaped container. The selected option is highlighted with the primary color.
Example usage:
SubZeroSwitch(
value: true,
onChanged: (value) => setState(() => _isEnabled = value),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SubZeroSwitch
- Available extensions
Constructors
-
SubZeroSwitch({Key? key, required bool value, required ValueChanged<
bool> ? onChanged, String activeLabel = 'YES', String inactiveLabel = 'NO', SubZeroSwitchSize size = SubZeroSwitchSize.medium, bool enabled = true, String? semanticLabel}) -
const
Properties
- activeLabel → String
-
Label for the active/true state (default: 'YES')
final
- enabled → bool
-
Whether the switch is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveLabel → String
-
Label for the inactive/false state (default: 'NO')
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
bool> ? -
Callback when value changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Semantic label for accessibility
final
- size → SubZeroSwitchSize
-
Size variant of the switch
final
- value → bool
-
Current value of the switch (true = active/left option selected)
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SubZeroSwitch> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited