SubZeroLabeledBinaryToggle class
A labeled binary toggle with optional description.
Example usage:
SubZeroLabeledBinaryToggle(
label: 'Dark Mode',
description: 'Enable dark theme for the app',
value: _isDarkMode,
onChanged: (value) => setState(() => _isDarkMode = value),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SubZeroLabeledBinaryToggle
- Available extensions
Constructors
-
SubZeroLabeledBinaryToggle({Key? key, required String label, required bool value, required ValueChanged<
bool> ? onChanged, String? description, SubZeroToggleSize size = SubZeroToggleSize.medium, bool enabled = true, SubZeroToggleLabelPosition labelPosition = SubZeroToggleLabelPosition.start, Color? activeColor}) -
const
Properties
- activeColor → Color?
-
Custom active track color
final
- description → String?
-
Optional description text below the label
final
- enabled → bool
-
Whether the toggle is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
Main label text
final
- labelPosition → SubZeroToggleLabelPosition
-
Position of the label relative to the toggle
final
-
onChanged
→ ValueChanged<
bool> ? -
Callback when value changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → SubZeroToggleSize
-
Size variant
final
- value → bool
-
Current toggle value
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited