SubZeroElevation class

Constructors

SubZeroElevation()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

level1 List<BoxShadow>
no setter
level2 List<BoxShadow>
no setter
level3 List<BoxShadow>
no setter
level4 List<BoxShadow>
no setter
none List<BoxShadow>
no setter