SubZeroRadius class

Constructors

SubZeroRadius()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

extraLarge BorderRadius
no setter
large BorderRadius
no setter
medium BorderRadius
no setter
rounded BorderRadius
no setter
small BorderRadius
no setter

Constants

lg → const double
md → const double
pill → const double
sm → const double
xl → const double
xs → const double