SubzeroElevationTokens class

Elevation / shadow tokens.

Avoid ad-hoc shadows; use one of the levels below.

Properties

e0 List<BoxShadow>
elevation.0 = none
no setter
e1 List<BoxShadow>
elevation.1 = 0px 1px 3px rgba(0,0,0,0.12)
no setter
e2 List<BoxShadow>
elevation.2 = 0px 3px 6px rgba(0,0,0,0.16)
no setter
e3 List<BoxShadow>
elevation.3 = 0px 6px 12px rgba(0,0,0,0.18)
no setter
e4 List<BoxShadow>
elevation.4 = 0px 12px 24px rgba(0,0,0,0.22)
no setter
e5 List<BoxShadow>
elevation.5 = 0px 16px 32px rgba(0,0,0,0.24)
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited