SubzeroFontFamilyTokens class

Font family stack.

Properties

fallbacks List<String>
Fallback stack.
final
hashCode int
The hash code for this object.
no setterinherited
primary String
Primary family name used by Flutter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited