SubzeroRadiusTokens class

Radius tokens.

Use these to create consistent corner rounding across components.

Properties

full double
final
hashCode int
The hash code for this object.
no setterinherited
lg double
final
lgCircular BorderRadius
no setter
md double
final
mdCircular BorderRadius
no setter
none double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
final
smCircular BorderRadius
no setter
xl double
final
xlCircular BorderRadius
no setter

Methods

circular(double r) BorderRadius
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited