SubzeroSemanticRamp class

Semantic color group with 100/500/700 variants.

Constructors

SubzeroSemanticRamp({required Color c100, required Color c500, required Color c700})
const

Properties

c100 Color
final
c500 Color
final
c700 Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int step) Color