SubzeroSpacingTokens class

Spacing tokens (8px base grid).

Use these for padding, gaps, and layout dimensions.

Properties

hashCode int
The hash code for this object.
no setterinherited
lg double
final
md double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
final
x2l double
final
x3l double
final
x4l double
final
xl double
final
xs double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited