SubzeroTextToken class

A text token with additional behavioral hints.

Constructors

SubzeroTextToken({required TextStyle style, bool uppercase = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle
The base style (color is intentionally not embedded).
final
uppercase bool
True when the consumer should render the text in uppercase.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited