SubzeroTokens class
Root token tree.
Properties
- color → SubzeroColorTokens
-
Color tokens: brand palette, neutrals, semantics, and aliases.
final
- dataviz → SubzeroDataVizTokens
-
Data visualization tokens: categorical + gradients.
final
- elevation → SubzeroElevationTokens
-
Elevation tokens: shadows.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- radius → SubzeroRadiusTokens
-
Radius tokens: corners and pill shapes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → SubzeroSpacingTokens
-
Spacing tokens: 8px base grid.
final
- typography → SubzeroTypographyTokens
-
Typography tokens: type scale + weights.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited