build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
return Scaffold(
appBar: AppBar(
title: const Text('Sub Zero 2.0 Design System'),
backgroundColor: SubZeroColors.surface,
elevation: 0,
titleTextStyle: SubZeroTypography.textTheme.titleLarge?.copyWith(
color: SubZeroColors.primary,
),
),
body: SingleChildScrollView(
padding: const EdgeInsets.all(SubZeroSpacing.lg),
child: Center(
child: ConstrainedBox(
constraints: const BoxConstraints(maxWidth: SubZeroSpacing.containerMaxWidth),
child: Column(
crossAxisAlignment: CrossAxisAlignment.start,
children: [
_buildSectionHeader('Colors'),
const SizedBox(height: SubZeroSpacing.md),
_buildColorSection(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Typography'),
const SizedBox(height: SubZeroSpacing.md),
_buildTypographySection(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Radius & Elevation'),
const SizedBox(height: SubZeroSpacing.md),
_buildRadiusElevationSection(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Spacing'),
const SizedBox(height: SubZeroSpacing.md),
_buildSpacingSection(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Accordion'),
const SizedBox(height: SubZeroSpacing.md),
_buildAccordionSection(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Add Item'),
const SizedBox(height: SubZeroSpacing.md),
const AddItemShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Avatar'),
const SizedBox(height: SubZeroSpacing.md),
const AvatarShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Badge'),
const SizedBox(height: SubZeroSpacing.md),
const BadgeShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Bottom Sheet'),
const SizedBox(height: SubZeroSpacing.md),
const BottomSheetShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Buttons'),
const SizedBox(height: SubZeroSpacing.md),
const ButtonShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Cards'),
const SizedBox(height: SubZeroSpacing.md),
const CardShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Carousel'),
const SizedBox(height: SubZeroSpacing.md),
const CarouselShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Checkbox & Multiselect'),
const SizedBox(height: SubZeroSpacing.md),
const CheckboxShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Dialog'),
const SizedBox(height: SubZeroSpacing.md),
const DialogShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Divider'),
const SizedBox(height: SubZeroSpacing.md),
const DividerShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Header'),
const SizedBox(height: SubZeroSpacing.md),
const HeaderShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Onboarding & Coachmarks'),
const SizedBox(height: SubZeroSpacing.md),
const OnboardingShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Progress Tracker'),
const SizedBox(height: SubZeroSpacing.md),
const ProgressTrackerShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Radio Button'),
const SizedBox(height: SubZeroSpacing.md),
const RadioButtonShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Search'),
const SizedBox(height: SubZeroSpacing.md),
const SearchShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Slider'),
const SizedBox(height: SubZeroSpacing.md),
const SliderShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Switch / Toggle'),
const SizedBox(height: SubZeroSpacing.md),
const SwitchShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Tabs'),
const SizedBox(height: SubZeroSpacing.md),
const TabsShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Tags / Chips'),
const SizedBox(height: SubZeroSpacing.md),
const TagShowcase(),
const SizedBox(height: SubZeroSpacing.xxl),
_buildSectionHeader('Toast'),
const SizedBox(height: SubZeroSpacing.md),
const ToastShowcase(),
],
),
),
),
),
);
}