AppSpacing class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- horizontalLg → const EdgeInsets
- horizontalMd → const EdgeInsets
- horizontalSm → const EdgeInsets
- horizontalXl → const EdgeInsets
- horizontalXs → const EdgeInsets
- lg → const double
- md → const double
- paddingLg → const EdgeInsets
- paddingMd → const EdgeInsets
- paddingSm → const EdgeInsets
- paddingXl → const EdgeInsets
- paddingXs → const EdgeInsets
- sm → const double
- verticalLg → const EdgeInsets
- verticalMd → const EdgeInsets
- verticalSm → const EdgeInsets
- verticalXl → const EdgeInsets
- verticalXs → const EdgeInsets
- xl → const double
- xs → const double
- xxl → const double