DarkModeColors class
Dark mode colors with good contrast
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- darkError → const Color
- darkErrorContainer → const Color
- darkInversePrimary → const Color
- darkOnError → const Color
- darkOnErrorContainer → const Color
- darkOnPrimary → const Color
- darkOnPrimaryContainer → const Color
- darkOnSecondary → const Color
- darkOnSurface → const Color
- darkOnSurfaceVariant → const Color
- darkOnTertiary → const Color
- darkOutline → const Color
- darkPrimary → const Color
- darkPrimaryContainer → const Color
- darkSecondary → const Color
- darkShadow → const Color
- darkSurface → const Color
- darkSurfaceVariant → const Color
- darkTertiary → const Color