FontSizes class

Font size constants

Constructors

FontSizes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bodyLarge → const double
bodyMedium → const double
bodySmall → const double
displayLarge → const double
displayMedium → const double
displaySmall → const double
headlineLarge → const double
headlineMedium → const double
headlineSmall → const double
labelLarge → const double
labelMedium → const double
labelSmall → const double
titleLarge → const double
titleMedium → const double
titleSmall → const double