LightModeColors class
Modern, neutral color palette for light mode Uses soft grays and blues instead of purple for a contemporary look
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lightBackground → const Color
- lightError → const Color
- lightErrorContainer → const Color
- lightInversePrimary → const Color
- lightOnError → const Color
- lightOnErrorContainer → const Color
- lightOnPrimary → const Color
- lightOnPrimaryContainer → const Color
- lightOnSecondary → const Color
- lightOnSurface → const Color
- lightOnSurfaceVariant → const Color
- lightOnTertiary → const Color
- lightOutline → const Color
- lightPrimary → const Color
- lightPrimaryContainer → const Color
- lightSecondary → const Color
- lightShadow → const Color
- lightSurface → const Color
- lightSurfaceVariant → const Color
- lightTertiary → const Color