SubZeroAccordionSection class
A single section inside SubZeroAccordion.
Each section has:
- title: header text.
- content: widget rendered when expanded.
- leadingIcon: optional icon rendered at the start of the header.
Constructors
- SubZeroAccordionSection({required String title, required Widget content, IconData? leadingIcon})
-
const
Properties
- content → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingIcon → IconData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited