SubZeroCardHeader class
Header configuration for SubZeroCard.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- leading → Widget?
-
Optional leading widget (e.g., icon or avatar)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional subtitle text
final
- subtitleMaxLines → int
-
Maximum lines for subtitle before ellipsis
final
- title → String
-
Primary title text
final
- titleMaxLines → int
-
Maximum lines for title before ellipsis
final
- trailing → Widget?
-
Optional trailing widget (e.g., icon button or badge)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited