SubZeroCardMedia class
Media configuration for SubZeroCard.
Constructors
- SubZeroCardMedia({String? image, String? imageUrl, Widget? child, SubZeroCardMediaRatio aspectRatio = SubZeroCardMediaRatio.standard, BoxFit fit = BoxFit.cover, String? semanticLabel})
-
const
Properties
- aspectRatio → SubZeroCardMediaRatio
-
Aspect ratio preset
final
- child → Widget?
-
Custom widget (e.g., chart, video player)
final
- fit → BoxFit
-
How the image should fit within the container
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → String?
-
Asset image path
final
- imageUrl → String?
-
Network image URL
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Accessibility label for the media
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited