components/subzero_carousel library
Classes
- SubZeroCarousel
- A carousel/slider component that displays a series of content items with navigation controls and indicators following SubZero 2.0 Design System.
- SubZeroCarouselBanner
- A banner-style carousel item with full-bleed content.
- SubZeroCarouselCard
- A pre-built carousel item card with image, title, and description.
- SubZeroCarouselConfig
- Configuration for the SubZeroCarousel component.
- SubZeroCarouselController
- Controller for external control of the SubZeroCarousel.