SubZeroCarouselController class

Controller for external control of the SubZeroCarousel.

Constructors

SubZeroCarouselController()

Properties

currentPage int?
Get the current page index.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

goToPage(int page) → void
Navigate to a specific page index.
nextPage() → void
Navigate to the next slide.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previousPage() → void
Navigate to the previous slide.
startAutoPlay() → void
Start auto-play if enabled in config.
stopAutoPlay() → void
Stop auto-play.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited