SubZeroCheckbox class
A customizable checkbox widget following SubZero 2.0 Design System.
Supports unchecked, checked, and indeterminate (tristate) states. The label is tappable and toggles the checkbox state.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SubZeroCheckbox
- Available extensions
Constructors
-
SubZeroCheckbox({Key? key, required bool? value, required ValueChanged<
bool?> ? onChanged, String? label, bool tristate = false, bool enabled = true, SubZeroCheckboxSize size = SubZeroCheckboxSize.medium, String? semanticLabel, TextStyle? labelStyle, Color? activeColor, Color? checkColor, Color? borderColor}) -
const
Properties
- activeColor → Color?
-
Custom active (checked/indeterminate) background color
final
- borderColor → Color?
-
Custom border color for unchecked state
final
- checkColor → Color?
-
Custom checkmark/minus icon color
final
- enabled → bool
-
Whether the checkbox is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Optional text label displayed next to the checkbox
final
- labelStyle → TextStyle?
-
Custom label text style
final
-
onChanged
→ ValueChanged<
bool?> ? -
Callback when checkbox state changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Semantic label for accessibility
final
- size → SubZeroCheckboxSize
-
Size of the checkbox
final
- tristate → bool
-
Whether to support indeterminate (null) state
final
- value → bool?
-
Current checkbox state: true (checked), false (unchecked), or null (indeterminate)
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SubZeroCheckbox> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited