SubZeroCoachMark class

A tooltip-style coachmark that highlights a specific UI element.

Example usage:

final targetKey = GlobalKey();

// In your widget tree
Container(key: targetKey, child: YourTargetWidget())

// To show coachmark
SubZeroCoachMark.show(
  context: context,
  targetKey: targetKey,
  title: 'New feature',
  description: 'Something about this feature and what it does.',
  position: SubZeroCoachMarkPosition.bottom,
);

Constructors

SubZeroCoachMark()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dismiss() → void
Dismiss the currently shown coachmark.
show({required BuildContext context, required GlobalKey<State<StatefulWidget>> targetKey, required String title, required String description, Widget? leadingWidget, SubZeroCoachMarkPosition position = SubZeroCoachMarkPosition.bottom, VoidCallback? onDismiss}) → void
Show a single coachmark tooltip pointing to a target widget.
showTour({required BuildContext context, required List<SubZeroCoachMarkStep> steps, VoidCallback? onComplete}) Future<void>
Show a series of coachmark steps sequentially.