SubZeroCoachMarkStep class
Configuration for a coachmark step.
Constructors
-
SubZeroCoachMarkStep({required GlobalKey<
State< targetKey, required String title, required String description, Widget? leadingWidget, SubZeroCoachMarkPosition position = SubZeroCoachMarkPosition.bottom})StatefulWidget> > -
const
Properties
- description → String
-
The description text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingWidget → Widget?
-
Optional leading icon/widget
final
- position → SubZeroCoachMarkPosition
-
Position of the tooltip relative to target
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetKey
→ GlobalKey<
State< StatefulWidget> > -
The GlobalKey of the target widget to highlight
final
- title → String
-
The title text
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited