SubZeroOnboardingCard class
A card-style onboarding component with media area, title, description, and action buttons.
Example usage:
SubZeroOnboardingCard(
title: 'New feature',
description: 'Something about this feature and what it does.',
mediaWidget: Icon(Icons.play_circle_outline, size: 48),
primaryButtonLabel: 'Show me more',
secondaryButtonLabel: 'Not interested',
onPrimaryPressed: () => print('Show more'),
onSecondaryPressed: () => print('Dismiss'),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SubZeroOnboardingCard
- Available extensions
Constructors
- SubZeroOnboardingCard({Key? key, required String title, required String description, Widget? mediaWidget, String? primaryButtonLabel, String? secondaryButtonLabel, VoidCallback? onPrimaryPressed, VoidCallback? onSecondaryPressed, bool showPrimaryTrailingIcon = true, bool showSecondaryTrailingIcon = true, double? width})
-
const
Properties
- description → String
-
The description text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mediaWidget → Widget?
-
Optional media widget (icon, image, video placeholder)
final
- onPrimaryPressed → VoidCallback?
-
Callback when primary button is pressed
final
- onSecondaryPressed → VoidCallback?
-
Callback when secondary button is pressed
final
- primaryButtonLabel → String?
-
Primary action button label
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryButtonLabel → String?
-
Secondary action button label
final
- showPrimaryTrailingIcon → bool
-
Whether to show trailing icon on primary button
final
- showSecondaryTrailingIcon → bool
-
Whether to show trailing icon on secondary button
final
- title → String
-
The title text
final
- width → double?
-
Card width constraint
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited