SubZeroOnboardingStep class
Configuration for an onboarding step.
Constructors
- SubZeroOnboardingStep({required String title, required String description, Widget? contentWidget})
-
const
Properties
- contentWidget → Widget?
-
Optional content widget (image, video, illustration)
final
- description → String
-
The description text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
The title text
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited