SubZeroProgressStep class
Data model for a single step in the progress tracker.
Constructors
- SubZeroProgressStep({required String title, IconData? icon, String? subtitle})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Optional icon to display instead of step number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional subtitle or description.
final
- title → String
-
The title/label of the step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited