SubZeroTabItem class

Configuration for a single tab

Constructors

SubZeroTabItem({required String label, IconData? icon, int? badgeCount, bool isDisabled = false})
const

Properties

badgeCount int?
Optional badge count
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional leading icon
final
isDisabled bool
Whether the tab is disabled
final
label String
The label text for the tab
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited