SubZeroToastConfig class
Configuration for toast display
Constructors
- SubZeroToastConfig({required String message, SubZeroToastType type = SubZeroToastType.defaultType, SubZeroToastPosition position = SubZeroToastPosition.bottom, SubZeroToastActionMode actionMode = SubZeroToastActionMode.icon, Duration duration = const Duration(seconds: 4), String? actionLabel, VoidCallback? onAction, IconData? leadingIcon, bool showCloseButton = true, double? maxWidth})
-
const
Properties
- actionLabel → String?
-
final
- actionMode → SubZeroToastActionMode
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingIcon → IconData?
-
final
- maxWidth → double?
-
final
- message → String
-
final
- onAction → VoidCallback?
-
final
- position → SubZeroToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool
-
final
- type → SubZeroToastType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited