SubZeroToggleGroup class
A group of toggles for managing multiple boolean settings.
Example usage:
SubZeroToggleGroup(
items: [
SubZeroToggleItem(label: 'Notifications', value: _notifications),
SubZeroToggleItem(label: 'Dark Mode', value: _darkMode),
SubZeroToggleItem(label: 'Auto-save', value: _autoSave),
],
onChanged: (index, value) {
setState(() {
if (index == 0) _notifications = value;
if (index == 1) _darkMode = value;
if (index == 2) _autoSave = value;
});
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SubZeroToggleGroup
- Available extensions
Constructors
-
SubZeroToggleGroup({Key? key, required List<
SubZeroToggleItem> items, required void onChanged(int index, bool value), SubZeroToggleSize size = SubZeroToggleSize.medium, double spacing = 16.0, bool showDividers = true}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
SubZeroToggleItem> -
List of toggle items
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onChanged → void Function(int index, bool value)
-
Callback when any toggle value changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDividers → bool
-
Whether to show dividers between items
final
- size → SubZeroToggleSize
-
Size variant for all toggles
final
- spacing → double
-
Spacing between items
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withCountBadge(
{required int count, int maxCount = 99, SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a count badge -
withDotBadge(
{SubZeroBadgeStyle style = SubZeroBadgeStyle.filled, SubZeroBadgeSize size = SubZeroBadgeSize.medium, SubZeroBadgeAlignment alignment = const SubZeroBadgeAlignment(), bool show = true}) → Widget -
Available on Widget, provided by the SubZeroBadgeExtension extension
Wrap this widget with a dot badge
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited