SubZeroToggleItem class
Data model for toggle group items
Constructors
- SubZeroToggleItem({required String label, required bool value, String? description, bool enabled = true})
-
const
Properties
- description → String?
-
Optional description text
final
- enabled → bool
-
Whether this toggle is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Label text for the toggle
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → bool
-
Current value of the toggle
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited